@@ -3,12 +3,16 @@
 void Generator::baseIncludes(ostream &out) const
 {
     bool interactive = d_options.interactive();
+    bool caseSensitive = d_options.caseSensitive();
+
+    if (interactive || not caseSensitive)
+        key(out);
 
     if (interactive)
-    {
-        key(out);
         out << "#include <sstream>\n";
-    }
+
+    if (not caseSensitive)
+        out << "#include <cctype>\n";
 
     if (!d_debug)
         return;
