@@ -3,6 +3,9 @@
 #include <sstream>
 #include <stdexcept>
 
+//FBB
+#include <filesystem>
+
 $insert class_ih
 
 $insert namespace-open
@@ -31,29 +34,26 @@ $insert inputImplementation
 
 \@Base::\@Base(std::istream &in, std::ostream &out)
 :
-    d_filename("-"),
     d_out(new std::ostream(out.rdbuf())),
 $insert interactiveInit
-    d_dfaBase_(s_dfa_)
-{}
 
 void \@Base::switchStream_(std::istream &in, size_t lineNr)
 {
-    d_input.close();
-    d_input = Input(new std::istream(in.rdbuf()), lineNr);
+    d_input->close();
+    d_streamStack.back().input = { new std::istream(in.rdbuf()), lineNr };
 }
 
 $ignoreInteractive BEGIN    this section is ignored by generator/filter.cc
 
 \@Base::\@Base(std::string const &infilename, std::string const &outfilename)
 :
-    d_filename(infilename),
     d_out(outfilename == "-"    ? new std::ostream(std::cout.rdbuf()) :
           outfilename == ""     ? new std::ostream(std::cerr.rdbuf()) :
                                   new std::ofstream(outfilename)),
-    d_input(new std::ifstream(infilename)),
     d_dfaBase_(s_dfa_)
-{}
+{
+    p_pushStream(infilename, { new std::ifstream(infilename) });
+}
 
 void \@Base::switchStreams(std::istream &in, std::ostream &out)
 {
@@ -63,9 +63,9 @@ void \@Base::switchStreams(std::istream &in, std::ostream &out)
 
 void \@Base::switchIstream(std::string const &infilename)
 {
-    d_input.close();
+    d_input->close();
     d_filename = infilename;
-    d_input = Input(new std::ifstream(infilename));
+    d_streamStack.back().input = new std::ifstream(infilename);
     d_atBOL = true;
 }
 
@@ -78,8 +78,7 @@ void \@Base::switchStreams(std::string const &infilename,
 
 void \@Base::pushStream(std::istream  &istr)
 {
-    std::istream *streamPtr = new std::istream(istr.rdbuf());
-    p_pushStream("(istream)", streamPtr);
+    p_pushStream("(istream)", new std::istream(istr.rdbuf())); //streamPtr);
 }
 
 void \@Base::pushStream(std::string const &name)
@@ -96,6 +95,38 @@ void \@Base::pushStream(std::string const &name)
 $ignoreInteractive END      end ignored section by generator/filter.cc
 
 
+// static
+std::string \@Base::setCwd(std::string const &name)     // any name
+{
+    using namespace std;
+    using namespace filesystem;
+
+    error_code ec;
+    if (not exists(name, ec))                           // not a filename
+        return name;
+                                                        // a filename: get its
+    auto path = canonical(name);                        // full pathname
+    current_path(path.parent_path(), ec);
+
+    return path.string();                               // return the pathname
+}
+
+void \@Base::p_pushStream(std::string const &name, std::istream *streamPtr)
+{
+    if (d_streamStack.size() == s_maxSizeofStreamStack_)
+    {
+        delete streamPtr;
+        throw std::length_error("Max stream stack size exceeded");
+    }
+
+    d_filename = name;
+    d_streamStack.push_back(StreamStruct{setCwd(d_filename), { streamPtr } });
+
+    d_input = &d_streamStack.back().input;
+
+    d_atBOL = true;
+}
+
 void \@Base::switchOstream(std::ostream &out)
 {
     *d_out << std::flush;
@@ -107,7 +138,7 @@ $insert debugFunctions
 void \@Base::redo(size_t nChars)
 {
     size_t from = nChars >= length() ? 0 : length() - nChars;
-    d_input.reRead(d_matched, from);
+    d_input->reRead(d_matched, from);
     d_matched.resize(from);
 }
 
@@ -120,33 +151,23 @@ void \@Base::switchOstream(std::string const &outfilename)
                                     new std::ofstream(outfilename));
 }
 
-void \@Base::p_pushStream(std::string const &name, std::istream *streamPtr)
-{
-    if (d_streamStack.size() == s_maxSizeofStreamStack_)
-    {
-        delete streamPtr;
-        throw std::length_error("Max stream stack size exceeded");
-    }
-
-    d_streamStack.push_back(StreamStruct{d_filename, d_input});
-    d_filename = name;
-    d_input = Input(streamPtr);
-    d_atBOL = true;
-}
 
 bool \@Base::popStream()
 {
-    d_input.close();
+    using namespace std::filesystem;
 
-    if (d_streamStack.empty())
+    d_input->close();
+
+    if (d_streamStack.size() <= 1)
         return false;
 
-    StreamStruct &top = d_streamStack.back();
-
-    d_input =   top.pushedInput;
-    d_filename = top.pushedName;
     d_streamStack.pop_back();
 
+    d_filename = 
+        path{ setCwd(d_streamStack.back().pushedName) }.filename().string();
+
+    d_input = &d_streamStack.back().input;
+
     return true;
 }
 
@@ -178,14 +199,14 @@ void \@Base::accept(size_t nChars)          // old name: less
 {
     if (nChars < d_matched.size())
     {
-        d_input.reRead(d_matched, nChars);
+        d_input->reRead(d_matched, nChars);
         d_matched.resize(nChars);
     }
 }
 
 void \@Base::setMatchedSize(size_t length)
 {
-    d_input.reRead(d_matched, length);  // reread the tail section
+    d_input->reRead(d_matched, length);  // reread the tail section
     d_matched.resize(length);           // return what's left
 }
 
@@ -198,7 +219,7 @@ void \@Base::setMatchedSize(size_t length)
 size_t \@Base::matched_(size_t ch)
 {
 $insert 4 debug "MATCH"
-    d_input.reRead(ch);
+    d_input->reRead(ch);
 
     FinalData *finalPtr;
                             
@@ -271,8 +292,8 @@ $insert 4 debug "ECHO_CH"
 void \@Base::echoFirst_(size_t ch)
 {
 $insert 4 debug "ECHO_FIRST"
-    d_input.reRead(ch);
-    d_input.reRead(d_matched, 1);
+    d_input->reRead(ch);
+    d_input->reRead(d_matched, 1);
     echoCh_(d_matched[0]);
 }
 
