@@ -69,7 +69,7 @@ protected:
     struct StreamStruct
     {
         std::string pushedName;
-        Input pushedInput;
+        Input input;
     };
 
 private:
@@ -93,7 +93,8 @@ private:
     std::istream *d_in;                     // points to the input stream
     std::shared_ptr<std::istringstream> d_line; // holds line fm d_in
     
-    Input           d_input;
+    Input           *d_input;               // input now in d_streamStack
+
     std::string     d_matched;              // matched characters
     std::string     d_lopMatched;           // matched lop-rule characters 
     std::string::iterator d_lopIter;
@@ -217,6 +218,8 @@ $insert startconddecl
     void setMatchedSize(size_t length);
     bool knownFinalState();
 
+    static std::string setCwd(std::string const &filename);
+
     template <typename ReturnType, typename ArgType>
     static ReturnType constexpr as(ArgType value);
     static bool constexpr available(size_t value);
@@ -224,7 +227,7 @@ $insert startconddecl
 
 inline \@Base::~\@Base()
 {
-    d_input.close();
+    d_input->close();
 }
 
 template <typename ReturnType, typename ArgType>
@@ -253,12 +256,12 @@ inline std::ostream &\@Base::out()
 
 inline void \@Base::push(size_t ch)
 {
-    d_input.reRead(ch);
+    d_input->reRead(ch);
 }
 
 inline void \@Base::push(std::string const &str)
 {
-    d_input.reRead(str, 0);
+    d_input->reRead(str, 0);
 }
 
 $ignoreInteractive BEGIN    this section is ignored by generator/filter.cc
@@ -308,7 +311,7 @@ inline void \@Base::leave(int retValue) const
 
 inline size_t \@Base::lineNr() const
 {
-    return d_input.lineNr();
+    return d_input->lineNr();
 }
 
 inline void \@Base::more()
@@ -328,7 +331,7 @@ inline size_t \@Base::get_()
 
 inline size_t \@Base::getInput()
 {
-    return d_input.get();
+    return d_input->get();
 }
 
 inline bool \@Base::return_()
