@@ -1,10 +1,9 @@
 #include "startconditions.ih"
-
     
 void StartConditions::useAll()
 {
     reset();
 
-    for(auto &mini: d_hash)
+    for(auto &mini: d_sc)
         d_active.push_back(&mini.second);
 }
