@@ -1,3 +1,4 @@
+//#define XERR
 #include "state.ih"
 
 State::State(size_t type, StateData *data)
@@ -5,4 +6,6 @@ State::State(size_t type, StateData *data)
     d_data(data),
     d_type(type),
     d_rule(-1)
-{}
+{
+    xerr((size_t)this % 1000 << ": d_data received");
+}
